###################################################
### chunk number 1: options
###################################################
options(continue="  ")
options(width=40)


###################################################
### chunk number 2:  eval=FALSE
###################################################
## help(package="SIM")


###################################################
### chunk number 3: 
###################################################
library(SIM)


###################################################
### chunk number 4: 
###################################################
data(expr.data)
data(acgh.data)
data(samples)  


###################################################
### chunk number 5: 
###################################################
names(expr.data)
names(acgh.data)    


###################################################
### chunk number 6: 
###################################################
acgh.data.only <- acgh.data[, 5:ncol(acgh.data)] 
expr.data.only <- expr.data[, 5:ncol(expr.data)] 
acgh.data.s <- acgh.data.only[, order(colnames(acgh.data.only))] 
expr.data.s <- expr.data.only[, order(colnames(expr.data.only))] 
sum(colnames(expr.data.s) == colnames(acgh.data.s))
acgh.data <- cbind(acgh.data[, 1:4], acgh.data.s) 
expr.data <- cbind(expr.data[, 1:4], expr.data.s)  


###################################################
### chunk number 7: 
###################################################
assemble.data(dep.data = acgh.data, 
              indep.data = expr.data, 
              dep.ann = colnames(acgh.data)[1:4], 
              indep.ann = colnames(expr.data)[1:4], 
              dep.id = "ID", 
              dep.chr = "CHROMOSOME", 
              dep.pos = "STARTPOS", 
              dep.symb = "Symbol", 
              indep.id = "ID", 
              indep.chr = "CHROMOSOME", 
              indep.pos = "STARTPOS", 
              indep.symb = "Symbol", 
              overwrite = TRUE, 
              run.name = "chr8q")


###################################################
### chunk number 8: 
###################################################
integrated.analysis(samples = samples, 
                    input.regions = "8q", 
                    zscores = TRUE, 
                    method = "full", 
                    run.name = "chr8q")  


###################################################
### chunk number 9: 
###################################################
sim.plot.pvals.on.genome(input.regions = "8q", 
                         adjust.method = "BY", 
                         run.name = "chr8q")


###################################################
### chunk number 10: 
###################################################
tabulate.pvals(input.regions = "8q", 
               adjust.method = "BY", 
               bins = c(0.001, 0.005, 0.01, 0.025, 0.05, 0.075, 0.1, 0.2, 1), 
               significance.idx=8, 
               run.name = "chr8q")


###################################################
### chunk number 11: 
###################################################
sim.plot.pvals.on.region(input.regions = "8q", adjust.method = "BY", run.name = "chr8q") 


###################################################
### chunk number 12: 
###################################################
opar <- par()


###################################################
### chunk number 13: 
###################################################
library(RColorBrewer)
sim.plot.zscore.heatmap(input.regions="8q", 
                        method="full", 
                        significance=0.005, 
                        z.threshold=3, 
                        colRamp=brewer.pal(11, "RdYlBu"), 
                        add.colRamp=rainbow(10),
                        show.names.indep=TRUE, 
                        show.names.dep=TRUE,
                        adjust.method="BY",                         
                        add.plot="smooth",
                        add.scale=c(-1, 3),
                        pdf=TRUE, 
                        run.name="chr8q")



###################################################
### chunk number 14: 
###################################################
par(opar)


###################################################
### chunk number 15: 
###################################################
table.dep <- tabulate.top.dep.features(input.regions = "8q",                                      
                                       adjust.method = "BY", 
                                       run.name = "chr8q")
head(table.dep[["8q"]])                  


###################################################
### chunk number 16: 
###################################################
table.indep <- tabulate.top.indep.features(input.regions = "8q", 
                                           adjust.method = "BY", 
                                           run.name = "chr8q")
head(table.dep[["8q"]])                        


###################################################
### chunk number 17: 
###################################################
sim.plot.overlapping.indep.dep.features(input.regions="8q", 
                                        adjust.method="BY", 
                                        significance=0.1, 
                                        z.threshold= c(-1,1),                                        
                                        log=TRUE,   
                                        summarize="consecutive",                                        
                                        pdf=TRUE, 
                                        method="full",
                                        run.name="chr8q")       


###################################################
### chunk number 18: 
###################################################
toLatex(sessionInfo())


